@@ -1,5 +1,10 @@
+import logging
+
 from .data_generators.patient_data_generator import PatientDataGenerator
 from .datasets.hdf5_dataset import PatientDataset
+from .logging_tools import logs_file_setup
+
+logs_file_setup(__file__, logging.INFO)
 
 __author__ = "Maxence Larose"
 __version__ = "0.1.1"
