@@ -13,8 +13,8 @@ def logs_file_setup(file: str, level=logging.INFO):
     logs_file = f'{logs_dir}/{os.path.splitext(os.path.basename(file))[0]}-{timestamp}.log'
     os.makedirs(logs_dir, exist_ok=True)
     logging.basicConfig(filename=logs_file, filemode='w+', level=level)
-    sh = logging.StreamHandler(sys.stdout)
-    logging.getLogger().addHandler(sh)
+    handler = logging.StreamHandler(sys.stdout)
+    logging.getLogger().addHandler(handler)
 
 
 if __name__ == '__main__':
